==> speech-analytic-testing_5.2.11_database.tar.gz: database/mssql/procedures/GetI6AlreadyRegisteredCallInteractions.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetI6AlreadyRegisteredCallInteractions] (@VCC VARCHAR(50) = NULL)
AS
BEGIN
	-- CRUZAMOS LA TABLA TEMPORAL CON LAS INTERACCIONES DE LA API CON LA TABLA AUDIO
	SELECT DISTINCT A.[VCC]														'vcc',
					CONCAT(A.[ID], '_', A.[Section], '_', A.[Part])				'ID',
					A.[ID]														'InteractionId',
					A.[Section]													'Secction',
					A.[Part]													'Part',
					'CALL'														'Channel',
					A.[Number]													'Number',
					A.[ContactAddress]											'ContactAdress',
					A.[Gender]													'Gender',
					A.[SilenceTime]												'SilenceTime',
					A.[DurationTime]											'DurationTime',
					A.[DurationTime]											'AttentionTime',
					1															'TotalParts',
					A.[Category1]												'Category1',
					A.[Category2]												'Category2',
					A.[Category3]												'Category3',
					A.[Description]												'Description',
					A.[DispositionCode]											'DispositionCode',
					A.[Campaign]												'Campaign',
					A.[Agent]													'Agent',
					A.[AgentName]												'agentName',
					A.[Type]													'Type',
					A.[StartDate]												'StartDate',
					A.[EndDate]													'EndDate',
					A.[Format]													'Format',
					ISNULL(A.[NeedI6Update], CAST(1 AS BIT))					'needI6Update'
		FROM [#InteractionsTemp] IT
		INNER JOIN [dbo].[Audio] A (NOLOCK)
			ON A.[VCC] = IT.[VCC]
				AND  A.[ID] = IT.[InteractionId]
		WHERE IT.[VCC] = @VCC
	

END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_6.5.0_database.tar.gz: database/mssql/procedures/GetI6AlreadyRegisteredCallInteractions.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetI6AlreadyRegisteredCallInteractions] (@VCC VARCHAR(50) = NULL)
AS
BEGIN
	-- CRUZAMOS LA TABLA TEMPORAL CON LAS INTERACCIONES DE LA API CON LA TABLA AUDIO
	SELECT DISTINCT A.[VCC]														'vcc',
					CONCAT(A.[ID], '_', A.[Section], '_', A.[Part])				'ID',
					A.[ID]														'InteractionId',
					A.[Section]													'Secction',
					A.[Part]													'Part',
					'CALL'														'Channel',
					A.[Number]													'Number',
					A.[ContactAddress]											'ContactAdress',
					A.[Gender]													'Gender',
					A.[SilenceTime]												'SilenceTime',
					A.[DurationTime]											'DurationTime',
					A.[DurationTime]											'AttentionTime',
					1															'TotalParts',
					A.[Category1]												'Category1',
					A.[Category2]												'Category2',
					A.[Category3]												'Category3',
					A.[Description]												'Description',
					A.[DispositionCode]											'DispositionCode',
					A.[Campaign]												'Campaign',
					A.[Agent]													'Agent',
					A.[AgentName]												'agentName',
					A.[Type]													'Type',
					A.[StartDate]												'StartDate',
					A.[EndDate]													'EndDate',
					A.[Format]													'Format',
					ISNULL(A.[NeedI6Update], CAST(1 AS BIT))					'needI6Update',
					A.[Ender]													'ender',
					A.[ticket]													'ticket'
		FROM [#InteractionsTemp] IT
		INNER JOIN [dbo].[Audio] A (NOLOCK)
			ON A.[VCC] = IT.[VCC]
				AND  A.[ID] = IT.[InteractionId]
		WHERE IT.[VCC] = @VCC
	

END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
